# -*- coding: UTF-8 -*-

import re
import shutil
import os

class Utils:

    # 最后数值加1，然后加上后缀
    @staticmethod
    def generate_verison(version, suffix):
        versions = re.findall(r"\d+", version)
        lastVersion = versions[-1]
        num = int(lastVersion) + 1
        newNum = str(num).zfill(3)
        versions[-1] = newNum
        return '.'.join(versions) + '-' + suffix

    # 使用指定后缀
    @staticmethod
    def generate_verison_with_suffix(version, suffix):
        versions = re.findall(r"\d+", version)
        return '.'.join(versions) + '-' + suffix

    @staticmethod
    def get_file_list(dir, fileType):
        file_list = []
        for home, dirs, files in os.walk(dir):
            for file_name in files:
                if(file_name[-len(fileType):] == fileType):
                    file_list.append(os.path.join(home, file_name))
        return file_list

    # 删除某一目录下的所有文件或文件夹 filepath: 路径
    @staticmethod
    def del_files(file_dir):
        if os.path.isdir(file_dir):
            del_list = os.listdir(file_dir)
            for f in del_list:
                file_path = os.path.join(file_dir, f)
                if os.path.isfile(file_path):
                    os.remove(file_path)
                elif os.path.isdir(file_path):
                    shutil.rmtree(file_path)
        else:
            print(file_dir + ' not exsit')


if __name__ == '__main__':

    version = Utils.generate_verison("1.2.222", "david")
    print(version)
    version = Utils.generate_verison_with_suffix('1.2.222-fix', 'david')
    print(version)

    # Utils.del_files("/Users/didi/Record/outputs")


# -*- coding: UTF-8 -*-

import configparser
import os

'''定义一个读取配置文件的类'''
class ReadConfig:
     
    def __init__(self, configName=None):
        root_dir = os.path.dirname(os.path.abspath('.'))
        # 当前文件所在目录
        filePath = os.path.dirname(os.path.realpath(__file__))
        print('root_dir:' + root_dir + ', filePath:' + filePath)
        if configName:
            self.configPath = os.path.join(root_dir, filePath + "/config/" + configName)
        else:
            self.configPath = os.path.join(root_dir, filePath + "/config/config.ini")
        self.cf = configparser.ConfigParser()
        self.cf.read(self.configPath)

    def get_value(self, section, key):
        if self.cf.has_option(section, key):
            value = self.cf.get(section, key)
        else:
            value = ''
        return value

    def set_value(self, section, key, value):
        self.cf.set(section, key, value)
        with open(self.configPath, 'w') as configFile:
             self.cf.write(configFile)


if __name__ == '__main__':
    test = ReadConfig('init.ini')
    # t = test.get_value("Version", "SugVersion")
    # print(t)
    # if t:
    #     print('is not null')
    # else:
    #     print('is null')

    test.set_value("INIT", "NeedInit", "false")





# -*- coding: UTF-8 -*-

from .readconfig import ReadConfig
from .build_mapflow import BuildMapFlow
from .build_global_passenger import BuildGlobalPassenger
import os
from .utils import *

class Init:
    
    def __init__(self):
        self.config = ReadConfig()
        #要改的文件类型（可以输入多个）
        self.file_type = [".gradle"]

    def init_mapflow(self):
        # sdk-mapflow/build.gradle中api 'com.xiaoju.nova:globalsug:2.2.090' 变更为api "com.xiaoju.nova:globalsug:${global_sug_sdk_version}"
        # sdk-mapflow/build.gradle中api 'com.xiaoju.nova:GlobalMapComponents:2.0.112' 变更为api "com.xiaoju.nova:GlobalMapComponents:${global_map_components_version}"
        #要改的文件夹
        project_dir = self.config.get_value("Project-Dir", "PassengerMapFlow")
        #替换表（可以用python正则表达式）
        lookup_table=[[".*api.+com.xiaoju.nova.globalsug.*", "api \"com.xiaoju.nova:globalsug:${global_sug_sdk_version}\""],
                       [".*api.+com.xiaoju.nova.GlobalMapComponents.*", "api \"com.xiaoju.nova:GlobalMapComponents:${global_map_components_version}\""]]
        utils.Replace.replace_strings(project_dir, self.file_type, lookup_table)

        # sdk-mapflow/gradle.properties中新增global_sug_sdk_version=2.2.131和global_map_components_version=2.0.129-david
        build_mapflow = BuildMapFlow()
        build_mapflow.setProperties("global_sug_sdk_version", "2.2.131")
        build_mapflow.setProperties("global_map_components_version", "2.0.129")

    def init_global_passenger(self):
        # build.gradle中删除ext.map_global_sdk_version = '3.2.355'
        # 要改的文件夹
        project_dir = self.config.get_value("Project-Dir", "GlobalPassenger")
        # 替换表（可以用python正则表达式）
        lookup_table=[[".*ext.map.global.sdk.version.*", ""]]
        utils.Replace.replace_strings(project_dir, self.file_type, lookup_table)
        
        # GlobalPassenger 工程 gradle.properties中新增map_global_sdk_version=3.2.366-david
        buildGlobalPassenger = BuildGlobalPassenger()
        buildGlobalPassenger.setProperties("map_global_sdk_version", "3.2.366")
    
    def init_python_env(self, build_path):
        alias = 'alias didi=\'python3 %s/build.py\'\n' % build_path
        homefolder = os.path.expanduser('~')
        bashrc = os.path.abspath('%s/.bash_profile' % homefolder)
        with open(bashrc, 'r') as f:
          lines = f.readlines()
          if alias not in lines:
            out = open(bashrc, 'a')
            out.write(alias)
            out.close()
          else:
            print('you had set alias didi, please delete the repeat setting.')
              
        os.system('source %s' % bashrc)

    def init(self):
        init_config = ReadConfig('init.ini')
        need_init = init_config.get_value("INIT", "needinit")
        if need_init == 'true':
            print('****************** init python environment ')
            build_path = os.path.dirname(os.path.realpath(__file__))
            print('build path :' + build_path)
            self.init_python_env(build_path)
            print('****************** init project *****************')
            init = Init()
            init.init_mapflow()
            init.init_global_passenger()
            init_config.set_value("INIT", "needinit", "false")
        else:
            print('you had inited, are you sure reinit?')


if __name__ == '__main__':
    Init().init()










#！/usr/bin/env python
#_*_coding:utf-8_*_
import os
import argparse
import textwrap
from dataclasses import dataclass
from typing import *
from pathlib import Path
import tempfile
from .android_string import Convert
from .simple_parsing import ArgumentParser, field, subparsers
from .pack import Config
from .pack import global_var
from .pack import build
from .simple_parsing.helpers import Serializable

Version = '1.0.6'

General_Description = '''
Common operation tools
Version %s
''' % Version

tmpdir = tempfile.gettempdir()
Cache_Path = os.path.join(tmpdir, 'aloon_cache.json')

@dataclass
class LocalCache(Serializable):
    configPath: str = ''

@dataclass
class Str2csv:
    """Covert android string to csv file, you can specified language, or export all by default."""

    def execute(self):
        Convert().run()


@dataclass
class Build:
    """A command to compile your project according to configuration.
       Start: 1、 aloon build -c 'Your JSON PATH'
              2、 aloon build -n 'Your project name or alias' -o 'i, u or other gradle task(e.g. assembleDebug)'
    """

    # name: input the name or alias configured in the JSON file 
    name:   str = field(alias=["-n"], default='')

    # option: i: installDebug  u: uploadArchives or gradle task name
    option:  str = field(alias=["-o"], default='')

    # config: specifies the path to the JSON file 
    config:  str = field(alias=["-c"], default='')

    def execute(self):
        if os.path.exists(Cache_Path):
            try:
                print(Cache_Path)
                localCache = LocalCache.load_json(Cache_Path)
                config = Config.load_json(localCache.configPath)
                global_var.set_value(global_var.CONFIG, config)
            except:
                os.remove(Cache_Path)
                print('json config error, please check and re-associated, run aloon build -c JSON path')
        else:
            if self.config is '':
                print('please associated json config file. run aloon build -c JSON path.')
                return
            else:
                config = Config.load_json(self.config)
                global_var.set_value(global_var.CONFIG, config)
                loaclCache = LocalCache()
                loaclCache.configPath = self.config
                loaclCache.save_json(Cache_Path)
                return

        if self.name is not '' and self.option is not '':
            build.build(self.name, self.option)
        else:
            print('Command need -n and -o, For details, please enter aloon build -h')

@dataclass
class Program:
    """Some top-level command"""
    command: Union[Str2csv, Build]

    # log additional messages in the console.
    verbose: bool = field(alias=["-v"], default=False)  
    
    def execute(self):
        print(f"Program (verbose: {self.verbose})")
        return self.command.execute()

def main():
    global_var._init()
    parser = ArgumentParser()
    parser.add_arguments(Program, dest="aloon")
    args = parser.parse_args()
    prog: Program = args.aloon

    prog.execute()
    
if __name__ == "__main__":
    main()


import argparse
import os
import sys
import getpass


class PromptParser(argparse.ArgumentParser):
    """
    Extends ArgumentParser to allow any unspecified arguments to be input dynamically on the command line
    """

    def add_argument(self, *args, prompt=True, secure=False, **kwargs):
        """
        For all unlisted arguments, refer to the parent class
        :param prompt: False if we never want to prompt the user for this argument
        :param secure: True if this argument contains sensitive information, and the input should not be shown on the
            command line while it's input.
        """
        if (
            prompt
            and kwargs.get("action") != "help"
            and not os.getenv("ARGPARSE_PROMPT_AUTO")
        ):
            # Wrap the Prompt type around the type the user wants
            type = Prompt(
                help=kwargs.get("help"),
                type=kwargs.get("type"),
                secure=secure,
                default=kwargs.get("default"),
            )

            # Remove the old type so we can replace it with our own
            if "type" in kwargs:
                del kwargs["type"]
            if "default" in kwargs:
                del kwargs["default"]

            # Delegate to the parent class. Default must be '' in order to get the type function to be called
            action = super().add_argument(*args, type=type, default="", **kwargs)

            # Set the argument name, now that the parser has parsed it
            type.name = action.dest

        else:
            super().add_argument(*args, **kwargs)


class Prompt:
    """
    A class the pretends to be a function so that it can be used as the 'type' argument for the ArgumentParser
    """

    def __init__(self, name=None, help=None, type=None, default=None, secure=False):
        """
        Creates a new prompt validator
        :param name: The identifier for the variable
        :param help: The help string to give the user when prompting
        :param type: The validation function to use on the prompted data
        :param secure: True if this argument contains sensitive information, and the input should not be shown on the
            command line while it's input.
        """
        self.type = type if type is not None else lambda x: x
        self.name = name
        self.help = help
        self.default = default
        self.secure = secure

    def __call__(self, val):
        default_str = f"({self.default}) "
        help_str = "" if self.help is None else f": {self.help}"

        try:
            # If the user provided no value for this argument, prompt them for it
            if val == "":
                prompt = "{}{}\n> {}".format(self.name, help_str, default_str)

                newval = (
                    getpass.getpass(prompt=prompt) if self.secure else input(prompt)
                )

                # If they just hit enter, they want the default value
                if newval == "":
                    newval = self.default

                # According to the argparse docs, if the default is a string we should convert it, but otherwise
                # we return it verbatim: https://docs.python.org/3/library/argparse.html#default
                if isinstance(newval, str):
                    return self.type(newval)
                else:
                    return newval

            return self.type(val)

        except BaseException:
            print(
                f'Argument "{self.name}" was given a value not of type {self.type}',
                file=sys.stderr,
            )
            exit(1)


# -*- coding: utf-8 -*-
 
CONFIG = 'config'

def _init():#初始化
    global _global_dict
    _global_dict = {}
 
 
def set_value(key,value):
    """ 定义一个全局变量 """
    _global_dict[key] = value
 
 
def get_value(key,defValue=None):
    """ 获得一个全局变量,不存在则返回默认值 """
    try:
        return _global_dict[key]
    except KeyError:
        return defValue


import os
import shutil

class FileUtils(object):
    '''
    用于操作文件的工具类
    :version 1.0
    :Python version : 3.6
    :author : YJK923

    '''

    @staticmethod
    def read(self,file_name,mode):
        '''
        读取文件内容，返回文件内容，类型为字符串，若文件不存在，则返回空
        ：prarm file_name : 文件名
                mode : 打开模式，常用方式 r 或 rb
                    r : 以读方式打开，只能读文件
                    rb : 以二进制读方式打开，只能读文件
                    rt : 以文本读方式打开，只能读文件
                    rb+ : 以二进制方式打开，可以读写文件
        '''
        try:
            with open(file_name,mode) as f:
                f.seek(0) # 移动文件指针
                content = f.read()
                return content
        except Exception as e :
            print(e)

    @staticmethod
    def readline(self,file_name):
        '''
        一行一行的读取文件
        :param : file_name : 文件名
        '''
        try:
            with open(file_name,'r') as f:
                for line in f:
                    print(line)
        except Exception as e:
            print(e)

    @staticmethod
    def write(self,file_name,content,mode):
        '''
        清空文件并写入 content
        :param file_name : 文件名
               content : 写入内容
               mode : 打开模式，常用方式 w 或 wb 
                   w : 以写的方式打开，只能写文件，若文件不存在，先创建，再写
                   wb : 以二进制写方式打开，只能写文件，若文件不存在，先创建再写，反之，清空之后再写
                   wt : 以文本方式打开，只能写文件，若文件不存在，先创建再写，反之，清空之后再写
        '''         
        with open(file_name,mode) as f:
            f.write(str(content))

    @staticmethod
    def append_write(self,file_name,content):
        '''
        追加文件写入 content
        :param file_name : 文件名
               content : 追加内容
        '''
        with open(file_name,'a+') as f:
            f.write(str(content))

    @staticmethod
    def clear(self,file_name):
        '''
        清空文件内容
        :param: file_name : 文件名
        '''
        with open(file_name,'wb') as f:
            f.truncate() # 清空文件内容

    @staticmethod
    def remove(self,file_name):
        '''
        删除文件
        :param : file_name : 文件名
        '''
        try:
            os.remove(file_name)
        except Exception as e:
            print(e)

    @staticmethod
    def tell(self,file_name):
        '''
        获取文件中指针的值
        :param : file_name : 文件名
        '''
        try:
            with open(file_name,'a+') as f:
                L = f.tell()
                return L
        except Exception as e:
            print(e)

    @staticmethod
    def copyfile(self,source_name,target_name):
        '''
        复制文件，复制之后的文件在同一级目录中
        :param : source_name : 原文件名
                 target_name : 复制之后的文件名 
        '''
        try:
            with open(source_name,'rb') as f1, open(target_name,'wb') as f2:
                f2.write(f1.read())
        except Exception  as e:
            print(e)

    @staticmethod
    def movefile(self,source_name,path):
        '''
        移动文件到 path 路径下 示例：movefile('users.txt','D:\\FTPTest')
        :param : source_name : 原文件名称
                 path : 移动之后的目录信息
        '''
        try:
            with open(source_name,'rb') as f1, open(path+'\\'+source_name,'wb') as f2:
                f2.write(f1.read())
            os.remove(source_name)
        except Exception as e:
            print(e)
    
    # 删除某一目录下的所有文件或文件夹 filepath: 路径
    @staticmethod
    def del_files(file_dir):
        if os.path.isdir(file_dir):
            del_list = os.listdir(file_dir)
            for f in del_list:
                file_path = os.path.join(file_dir, f)
                if os.path.isfile(file_path):
                    os.remove(file_path)
                elif os.path.isdir(file_path):
                    shutil.rmtree(file_path)
        else:
            print(file_dir + ' not exsit')



from ..simple_parsing import ArgumentParser, field, subparsers
from ..simple_parsing.helpers import Serializable
from dataclasses import dataclass

@dataclass
class Dependency(Serializable):
    name:                str = ''
    gradle_placeholder:  str = ''

@dataclass
class Module(Serializable):
    name:                        str  = ''
    alias:                       str  = ''
    path:                        str  = ''
    build:                       str = ''
    upload_version:              str = ''
    upload_version_placeholder:  str = ''
    dependencies:                list[Dependency] = field(default_factory=list)

@dataclass
class Config(Serializable):
    suffix:              str = ''
    outputs:             str = ''
    projects:            list[Module] = field(default_factory=list)



# -*- coding: UTF-8 -*-

from logging import PlaceHolder
import os
import re

class Replace:

    @staticmethod
    def get_file_list(dir, file_type):
        file_list = []
        for home, dirs, files in os.walk(dir):
            for file_name in files:
                if(file_name[-len(file_type):] == file_type):
                    file_list.append(os.path.join(home, file_name))
        return file_list

    @staticmethod
    def replace_strings(dir, file_type, lookup_table):
        for type in file_type:
            print("开始处理" + type + "类型文件")
            file_list = Replace.get_file_list(dir, type)
            print("共发现" + str(len(file_list)) + "个" + type + "类型文件")
            replace_count = 0
            file_count = 0
            for file in  file_list:
                file_count = file_count + 1
                if(file_count % 100 == 0):
                    print("修改到第" + str(file_count) + "个文件")
                file_data = ""
                with open(file, "r", encoding = "utf-8") as f:
                    for line in f:
                        for item in lookup_table:
                            if re.search(item[0], line):
                                print("--------------- line" + line)
                                #print("正在修改从"+item[0]+"到"+item[1])
                                line = re.sub(item[0], item[1], line)
                                replace_count = replace_count + 1
                        file_data += line
                with open(file, "w", encoding="utf-8") as f:
                    f.write(file_data)
            print("一共进行了" + str(replace_count) + "处替换")
            print("结束处理" + type + "类型文件")
        print("全部结束")
    
    @staticmethod
    def get_string(dir, file_type, lookup_str):
        for type in file_type:
            print("开始处理" + type + "类型文件")
            file_list = Replace.get_file_list(dir, type)
            print("共发现" + str(len(file_list)) + "个" + type + "类型文件")
            file_count = 0
            for file in  file_list:
                file_count = file_count + 1
                if(file_count % 100 == 0):
                    print("修改到第" + str(file_count) + "个文件")
                with open(file, "r", encoding = "utf-8") as f:
                    for line in f:
                        if re.search(lookup_str, line):
                            print(line + '--------------')
                            return re.findall(lookup_str, line)[0]
        return ''

if __name__ == "__main__":
    fileType = [".gradle", ".properties"]
    
    # placeHolder = 'map_global_sdk_version'
    # value = '888888888'
    # lookup_table=[[ placeHolder + '[\s]*[=][\s]*.*', '%s='%placeHolder + value]]
    # Replace.replace_strings('/Users/didi/DidiProjects/GlobalPassenger', fileType, lookup_table)
    placeHolder = 'VERSION'
    lookup_str = '^\s*e?x?t?\.?' + placeHolder + '[\s]*[=][\s]*(.*)'
    version = Replace.get_string('/Users/didi/DidiProjects/PassengerMapFlow', fileType, lookup_str)
    print(version + '+++++++')
    
    pass






from genericpath import exists
import os, collections
from os.path import curdir
from xml.dom import minidom
import codecs
import io
from .ordered_set import OrderedSet

class Convert:

  DEBUG = False

  def unescapeAndroidChar(self, text):
      text = text.replace("\\'", '\'')
      return text

  def getLangsFromDir(self, res_path):
    curdir = os.getcwd()
    os.chdir(res_path)
    langs = []
    for x in os.walk('.'):
        code = self.getLangDir(x[0])
        if code is not None:
            langs.append(code)
    os.chdir(curdir)
    return langs
  
  def getLangDir(self, dir_name):
    """
    Supported langauge directories follow one of three patterns:
    https://support.google.com/googleplay/android-developer/table/4419860
    1) values-**
    2) values-**-**
    3) values-**-***
    returns code for language or None if not a language directory
    """
    if dir_name[2:].startswith('values-'):
        code = [dir_name[9:]][0]
        if (len(code) == 2) or (len(code) == 5 and code[2] == '-') \
                or (len(code) == 6 and code[2] == '-'):
            return code

    # not a language dir
    return None

  def fetchLanguageFromInput(self, resourcePath):
      language = input('export language list. if don\'t input, export all. (e.g.: \'zh-rCN es-rCL\'):')
      allLans = self.getLangsFromDir(resourcePath)
      if not language:
        exportLans = allLans
      else:
        exportLans = language.split(' ')
        if set(exportLans) <= set(allLans):
          pass
        else:
          print('language input error, can\'t find these languages, please input again.')
          exportLans = self.fetchLanguageFromInput(resourcePath)
      return exportLans
  
  def fetchResourcePathFromInput(self):
      path = input('Path to Android project resource directory. (e.g.: \'/root/user/project/module/src/main/res\':')
      if not os.path.exists(path):
        print('input path isn\'t exsit, make sure path is correct')
        path = self.fetchResourcePathFromInput()
      return path

  def fetchOutputFilePathFromInput(self):
      path = input('Path to CSV file (output). (e.g.: \'/root/user/directory/csvname.csv\')')
      if not path:
        curdir = os.getcwd()
        path = curdir + "/android-string.csv"
      self.create_file(path)
      return path
  
  def create_file(self, filename):
        path = filename[0:filename.rfind("/")]
        if not os.path.isdir(path):
            os.makedirs(path)
        if not os.path.isfile(filename):
            fd = io.open(filename, mode="w", encoding="utf-8")
            fd.close()
        else:
            pass

  def run(self):
    print('************** attention: input content use \'\'**********************')
    resourcePath = self.fetchResourcePathFromInput()
    exportLans = self.fetchLanguageFromInput(resourcePath)
    outputFilePath = self.fetchOutputFilePathFromInput()
    self.convert(exportLans, resourcePath, outputFilePath)
    pass

  def convert(self, lans, resourcePath, outputFilePath):
    csvSep = "\t"
    resourcePath = resourcePath
    outputFilePath = outputFilePath
    exportLanguages = lans
    folderList = os.listdir(resourcePath)
    languageDict = dict()
    for f in folderList:
      if f.startswith("values"):
        if f == 'values':
          curLanguage = 'default' 
        else:
          curLanguage = f.replace('values-', '')
        if curLanguage in exportLanguages or curLanguage == 'default':
          languageDict[curLanguage] = dict()
          stringsDict = languageDict[curLanguage]
          valuesPath = os.path.join(resourcePath,f)
          if os.path.isdir(valuesPath):
            filePath = os.path.join(valuesPath, "strings.xml")
            if os.path.exists(filePath):
              #Open String XML
              #print(filePath)
              xmldoc = minidom.parse(filePath)
              rootNode = xmldoc.getElementsByTagName("resources")
              if len(rootNode) == 1:          
                nodeList = rootNode[0].childNodes
                for n in nodeList:
                  attr = n.attributes
                  if attr != None:
                    tag = n.tagName
                    if tag == 'string':
                      key = attr['name'].nodeValue
                      value = n.childNodes[0].nodeValue
                      stringsDict[key] = value.strip()
                      #print(key + " = " + value)
                    elif tag == 'string-array':
                      name = attr['name'].nodeValue
                      itemList = n.getElementsByTagName("item")
                      for idx, item in enumerate(itemList):
                        key = str(name)+","+str(idx)
                        value = item.childNodes[0].nodeValue
                        #print(key + " = " + value)
                        stringsDict[key] = value.strip()
                    else:
                      if self.DEBUG:
                        print("Unknown node")
            else:
              if self.DEBUG:
                print('Invalid ressource file. We expect a ressources node')
            #for s in itemlist :          
              #print(s)

    #Get all key list
    uniqueKeys = set()
    for k in languageDict:
      stringsDict = languageDict[k]
      for keys in stringsDict:
        uniqueKeys.add(keys)
    uniqueKeys = OrderedSet(sorted(uniqueKeys))

    #Write CSV
    with codecs.open(outputFilePath, 'w', "utf-8") as f:
      f.write(u'\ufeff') #UTF8 Marker
      f.write("key" + csvSep)
      for k in languageDict:
        f.write(k + csvSep)
      for key in uniqueKeys:
        f.write("\n")
        f.write(key+csvSep)
        totalCount = len(languageDict)
        for k in languageDict:
          stringsDict = languageDict[k]
          if key in stringsDict:
              f.write(self.unescapeAndroidChar(stringsDict[key]) + csvSep) 
          else:
              f.write(" " + csvSep)
    print('string convert success, csv file saved path: ' + outputFilePath)

  def test(self):
      # lans = 'zh-rCN es-rCL'
      outpath = os.getcwd() + "/android-string.csv"
      resPath = '/Users/didi/DidiProjects/PassengerSug-dev/global_sug/src/main/res'
      lans = self.getLangsFromDir(resPath)
      Convert().convert(lans, resPath, outpath)
      pass

if __name__ == "__main__":
    Convert().run()
    pass


import os
import sys
import setuptools

version = '1.0.7'

def read(f):
    return open(os.path.join(os.path.dirname(__file__), f)).read().strip()

packages = setuptools.find_namespace_packages(include=['aloon*'])


setuptools.setup(name='aloon',
      version=version,
      description=('Common helper'),
      long_description='\n\n'.join((read('DESCRIBE.md'), read('CHANGELOG'))),
      classifiers=[
          'License :: OSI Approved :: BSD License',
          'Intended Audience :: Developers',
          'Programming Language :: Python'],
      keywords='android localization translation translate',
      author='David',
      author_email='dww410@163.com',
      url='https://github.com/dww410/aloon',
      license='MIT',
      py_modules=['aloon'],
      namespace_packages =[ ],
      package_data={
        '': ['shell/*.sh', 'config/*.ini'],
      },
      packages=packages, 
      entry_points={
          'console_scripts': [
              'aloon = aloon:main']
      },
      python_requires='>=3.6',
      install_requires=[
          "typing_inspect",
          "dataclasses;python_version<'3.7'",
      ],
      include_package_data = False)



# -*- coding: UTF-8 -*-
from re import findall
import sys
import os
from .utils import Utils, Replace
from . import global_var
from . import Config, Module, Dependency

class BuildComponent:

    def __init__(self, projectName):
        self.config: Config = global_var.get_value(global_var.CONFIG)
        self.module: Module = self.findModule(self.config.projects, projectName)
        print(self.module)
        self.suffix = self.config.suffix
        self.outputs = self.config.outputs
        self.projectDir = self.module.path
    
    def findModule(self, projects: list, projectName):
      for project in projects:
          module: Module = project
          if (module.name == projectName or module.alias == projectName):
            return module
      return None
   
    def buildComponent(self, module: Module, option):
        # 只有执行upload时候，修改版本号
        version = module.upload_version
        if option == 'u':
            curVersion = ''
            if version:
                curVersion = Utils.generate_verison_with_suffix(version, self.suffix)
                print('config upload component version:' + version)
            else:
                oldVersion = self.getGradlePlaceHolderValue(module, module.upload_version_placeholder)
                print("oldVersion: " + oldVersion)
                if oldVersion != '':
                    newVersion = Utils.generate_verison(oldVersion, self.suffix)
                    curVersion = newVersion
                    print('don\'t config component upload version, need generate version, old version:' + oldVersion + ',generateVersion:' + newVersion)
                else:
                    print('can\'t fetch version code, check command right')
            self.setGradlePlaceHolderValue(module, module.upload_version_placeholder, curVersion)
        result = self.executeShell(option)
        if result != 0:
            sys.exit(0)
    
    def executeShell(self, option):
        print('execute component shell, option:' + option)
        # 当前文件所在目录
        file_path = os.path.dirname(os.path.realpath(__file__))
        return os.system(file_path + '/shell/build_component.sh ' + self.projectDir + ' ' + file_path + ' ' + option + ' ' + self.outputs)

    def handleDependencies(self):
        print('handle component dependencies')
        for dependency in self.module.dependencies:
            depend: Dependency = dependency
            self.handleDependencyModule(depend)
        
    def handleDependencyModule(self, dependency: Dependency):
        module: Module = self.findModule(self.config.projects, dependency.name)
        upload_version = module.upload_version
        if upload_version == '':
            # 没有指定module version时，先编译上传module，然后取module工程版本号
            buildComponent = BuildComponent(module.name)
            buildComponent.build('u')
            moduleVersion = buildComponent.getGradlePlaceHolderValue(module, module.upload_version_placeholder)
            print('don\'t config %s sdk version, fetch from sug project' % moduleVersion)
        else:
            moduleVersion = upload_version
        moduleVersion = Utils.generate_verison_with_suffix(moduleVersion, self.suffix)
        self.setGradlePlaceHolderValue(self.module, dependency.gradle_placeholder, moduleVersion)
        print('used %s sdk version:' % module.name + moduleVersion) 

    def setGradlePlaceHolderValue(self, module: Module, placeHolder, value):
        fileType = [".gradle", ".properties"]
        lookup_table=[[r'(^\s*e?x?t?\.?' + placeHolder + '[\s]*[=][\s]*)\'?[1-9]+.*\'$', "\\1\'%s\'" %value]]
        Replace.replace_strings(self.projectDir, fileType, lookup_table)

    def getGradlePlaceHolderValue(self, module: Module, placeHolder):
        fileType = [".gradle", ".properties"]
        lookup_str = '^\s*e?x?t?\.?' + placeHolder + '[\s]*[=][\s]*([1-9]+.*)'
        return Replace.get_string(self.projectDir, fileType, lookup_str)

    def build(self, option): 
        print('build module name: ' + self.module.name + ' ,build switch: ' + str(self.module.build))
        if self.module.build == 'true':
            print('buid component start...')
            self.handleDependencies()
            self.buildComponent(self.module, option)
            print('buid comonent end.')
        else:
            print('build closed, you can open it in config.')

    






# -*- coding: UTF-8 -*-
import sys
from .utils import Utils
from .build_component import BuildComponent

def build(projectName, op):
    if op is not None:
        option = op
    else:
        option = 'u'

    if projectName is not None:
        buildComponent = BuildComponent(projectName)
        buildComponent.build(option)
    else:

        print('')
        print('general commands:')
        print('sug                      build Sug library')
        print('map                      build MapCompoent library')
        print('mapflow                  build MapFlow library')
        print('99                       build GlobalPassenger apk')

        print('')
        print('global options:')
        print('default                  same as -u')
        print('-i                       build and install apk')
        print('-u                       upload library to maven')




